/*******************************************************************************
 * @AUTHOR Andr Hartmann <andre.hartmann@iseg-hv.de>
 * @BRIEF  Example programm to access the iseg MICC HV supplies over Ethernet.
 * This program sends the "*IDN?" (identification) command to the device
 * and prints out the returned device data.
 * This program was successfully compiled under Windows XP SP3 with:
 * - Borland C++ Builder 6.0
 * - Microsoft Visual C++ 6.0 (add wsock32.lib to Linker library modules)
 * - mingw32 4.4.0: gcc main.c -o socket -lwsock32
 * Warning: no error handling is done so far!
 * Please change the IP address settings according to your needs.
 */

#include <stdio.h>
#include <winsock.h>

int main(int argc, char *argv[])
{
	WSADATA     wsadata;
	SOCKET      sock;
	SOCKADDR_IN sockaddr_in;
	int         retcode;
	char        cmd[255] = "*IDN?\r\n";
	char        ans[255] = "";
	char        buf[255];
	char        *crlf;

	// init sockets (Berkeley style, UNIX compatible)
	WSAStartup(2, &wsadata);

	// create TCP socket
	sock = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);

	// bind socket to dynamic local port
	memset(&sockaddr_in, 0, sizeof(sockaddr_in));
	sockaddr_in.sin_family = AF_INET;            // UDP, TCP
	sockaddr_in.sin_port   = htons(10001);        // remote Port
	sockaddr_in.sin_addr.S_un.S_un_b.s_b1 = 192; // IP address
	sockaddr_in.sin_addr.S_un.S_un_b.s_b2 = 168;
	sockaddr_in.sin_addr.S_un.S_un_b.s_b3 =  16;
	sockaddr_in.sin_addr.S_un.S_un_b.s_b4 = 221;

	// connect to server (three way handshake)
	connect(sock, (SOCKADDR *)&sockaddr_in, sizeof(SOCKADDR_IN));

	// send command to server
	send(sock, cmd, strlen(cmd), 0);

	// read answer from server
	do {
		retcode = recv(sock, buf, sizeof(ans), 0);

		if (retcode > 0) {
			buf[retcode] = 0;
			strcat(ans, buf);
		}

		crlf = strstr(ans, "\r\n");
	} while ( (retcode > 0) && (crlf == 0) );

	if (crlf > 0) {
		*crlf = 0;
	}

	// close socket (three way handshake) and clean up
	closesocket(sock);
	WSACleanup();

	printf("%s\n", ans);

	getchar();

	return 0;
}

